# DPEA_DPi
DPEA Pi Family of Circuit Boards Developed by Stan Reifel 2022

This repo is for all of the DPi files to be added to a python package.


This package is on PyPi under the dpea account 
To maintain, clone the repository, edit files, recreate wheels - 'python3 setup.py sdist bdist_wheel', and upload the new files to testPyPi first then finally to PyPi.

More information:
https://gist.github.com/arsho/fc651bfadd8a0f42be72156fd21bd8a9 
